@@ -192,6 +192,29 @@ sub command_args {
         }
     }
     
+    foreach my $attribute ($self->command_usage_attributes($metaclass,'all')) {
+        next
+            unless $attribute->can('has_cmd_env')
+            && $attribute->has_cmd_env;
+        
+        my $cmd_env = $attribute->cmd_env;
+        
+        if (exists $ENV{$cmd_env}
+            && ! defined $return->{$attribute->name}) {
+            $return->{$attribute->name} = $ENV{$cmd_env};
+            my $error = $attribute->cmd_type_constraint_check($ENV{$cmd_env});
+            if ($error) {
+                push(@{$errors},
+                    $self->command_message(
+                        header          => "Invalid environment value for '".$cmd_env."'", # LOCALIZE
+                        type            => "error",
+                        body            => $error,
+                    )
+                );
+            }
+        }
+    }
+    
     return ($return,$errors);
 }
 
@@ -201,11 +224,10 @@ sub command_proto {
     $metaclass   ||= $self;
     
     my @attributes;
-    foreach my $attribute ($self->command_usage_attributes($metaclass)) {
+    foreach my $attribute ($self->command_usage_attributes($metaclass,'proto')) {
         next
             unless $attribute->does('AppOption')
-            && $attribute->has_cmd_type
-            && $attribute->cmd_type eq 'proto';
+            && $attribute->has_cmd_type;
         push(@attributes,$attribute);
     }
     
@@ -371,15 +393,21 @@ sub command_process_attribute {
                 )
             );
         } else {
-                        
             if ($attribute->should_coerce
                 && $type_constraint->has_coercion) {
                 my $coercion = $type_constraint->coercion;
                 $value = $coercion->coerce($value) // $value;
             }
-            my $error = $self->command_check_attribute($attribute,$value);
-            push(@errors,$error)
-                if $error;
+            my $error = $attribute->cmd_type_constraint_check($value);
+            if (defined $error) {
+                push(@errors,
+                    $self->command_message(
+                        header          => "Invalid value for '".$attribute->cmd_name_primary."'", # LOCALIZE
+                        type            => "error",
+                        body            => $error,
+                    )
+                );
+            }
         }
         
     } else {
@@ -389,104 +417,10 @@ sub command_process_attribute {
     return ($value,\@errors);
 }
 
-sub command_check_attribute {
-    my ($self,$attribute,$value) = @_;
-    
-    return 
-        unless ($attribute->has_type_constraint);
-    my $type_constraint = $attribute->type_constraint;
-    
-    # Check type constraints
-    unless ($type_constraint->check($value)) {
-        my $message;
-        
-        if (ref($value) eq 'ARRAY') {
-            $value = join(', ',@$value);
-        } elsif (ref($value) eq 'HASH') {
-            $value = join(', ',map { $_.'='.$value->{$_} } keys %$value)
-        }
-        
-        # We have a custom message
-        if ($type_constraint->has_message) {
-            $message = $type_constraint->get_message($value);
-        # No message
-        } else {
-            my $message_human = $self->command_type_constraint_description($type_constraint);
-            if (defined $message_human) {
-                $message = "Value must be ". $message_human ." (not '$value')";
-            } else {
-                $message = $type_constraint->get_message($value);
-            }
-        }
-        
-        return $self->command_message(
-            header          => "Invalid value for '".$attribute->cmd_name_primary."'", # LOCALIZE
-            type            => "error",
-            body            => $message,
-        );
-    }
-    
-    return;
-}
 
 
-sub command_type_constraint_description {
-    my ($self,$type_constraint,$singular) = @_;
-    
-    $singular //= 1;
-    
-    if ($type_constraint->isa('Moose::Meta::TypeConstraint::Enum')) {
-        return 'one of these values: '.join(', ',@{$type_constraint->values});
-    } elsif ($type_constraint->isa('Moose::Meta::TypeConstraint::Parameterized')) {
-        my $from = $type_constraint->parameterized_from;
-        if ($from->is_a_type_of('ArrayRef')) {
-            return $self->command_type_constraint_description($type_constraint->type_parameter);
-        } elsif ($from->is_a_type_of('HashRef')) {
-            return 'key-value pairs of '.$self->command_type_constraint_description($type_constraint->type_parameter,0);
-        }
-    # TODO union
-    } elsif ($type_constraint->equals('Int')) {
-        return $singular ? 'an integer':'integers'; # LOCALIZE
-    } elsif ($type_constraint->equals('Num')) {
-        return $singular ? 'a number':'numbers'; # LOCALIZE
-    } elsif ($type_constraint->equals('Str')) {
-        return $singular ? 'a string':'strings';
-    } elsif ($type_constraint->equals('HashRef')) {
-        return 'key-value pairs'; # LOCALIZE
-    }
-    
-    if ($type_constraint->has_parent) {
-        return $self->command_type_constraint_description($type_constraint->parent);
-    }
-    
-    return;
-    
-#    given ($type_constraint_name) {
-#        when ('Int') {
-#            return 'integer'; # LOCALIZE
-#        }
-#        when ('Num') {
-#            
-#        }
-#        when (/^ArrayRef\[(.*)\]$/) {
-#            return $self->command_type_constraint_description($1);
-#        }
-#        when ('HashRef') {
-#            return 'key-value pairs'; # LOCALIZE
-#        } 
-#        when (/^HashRef\[(.+)\]$/) {
-#            return 'key-value pairs with '.$self->command_type_constraint_description($1).' values'; # LOCALIZE
-#        }
-#        when ('Str') {
-#            return 'string'; # LOCALIZE
-#        }
-#        default {
-#            $type_constraint
-#        }
-#    }
-    
-    return;
-}
+
+
 
 sub command_candidates {
     my ($self,$command) = @_;
@@ -610,6 +544,28 @@ sub command_message {
     return $messageclass->new(@args);
 }
 
+sub command_check_attributes {
+    my ($self,$command_meta,$errors,$params) = @_;
+    
+    $command_meta ||= $self;
+    
+    # Check required values
+    foreach my $attribute ($self->command_usage_attributes($command_meta,[qw(option proto parameter)])) {
+        if ($attribute->is_required
+            && ! exists $params->{$attribute->name}
+            && ! $attribute->has_default) {
+            push(@{$errors},
+                $self->command_message(
+                    header          => "Required ".($attribute->cmd_type eq 'parameter' ? 'parameter':'option')." '".$attribute->cmd_name_primary."' missing", # LOCALIZE
+                    type            => "error",
+                )
+            );
+        }
+    }
+    
+    return $errors;
+}
+
 sub command_usage_attributes {
     my ($self,$metaclass,$types) = @_;
     
@@ -620,8 +576,11 @@ sub command_usage_attributes {
     foreach my $attribute ($metaclass->get_all_attributes) {
         next
             unless $attribute->does('AppOption')
-            && $attribute->has_cmd_type
-            && $attribute->cmd_type ~~ $types;
+            && $attribute->has_cmd_type;
+        
+        next
+            unless $types eq 'all'
+            || $attribute->cmd_type ~~ $types;
         
         push(@return,$attribute);
     }
@@ -690,18 +649,20 @@ sub command_usage_header {
     my ($command_name,$usage);
     if ($command_meta_class) {
         $command_name = $self->command_class_to_command($command_meta_class->name);
-        if ($command_meta_class->can('command_usage')
-            && $command_meta_class->command_usage_predicate) {
-            $usage = MooseX::App::Utils::format_text($command_meta_class->command_usage);
-        }
     } else {
         $command_name = '<command>';
     }
     
+    $command_meta_class ||= $self;
+    if ($command_meta_class->can('command_usage')
+        && $command_meta_class->command_usage_predicate) {
+        $usage = MooseX::App::Utils::format_text($command_meta_class->command_usage);
+    }
+    
     unless (defined $usage) {
         # LOCALIZE
         $usage = "$caller $command_name ";
-        my @parameter= $self->command_usage_attributes($command_meta_class||$self,'parameter');
+        my @parameter= $self->command_usage_attributes($command_meta_class,'parameter');
         foreach my $attribute (@parameter) {
             if ($attribute->is_required) {
                 $usage .= "<".$attribute->cmd_usage_name.'> ';
@@ -725,7 +686,6 @@ sub command_usage_description {
     my ($self,$command_meta_class) = @_;
     
     $command_meta_class ||= $self;
-    
     if ($command_meta_class->can('command_long_description')
         && $command_meta_class->command_long_description_predicate) {
         return $self->command_message(
@@ -968,19 +928,6 @@ command. Is a wrapper around L<command_parse_options>.
 
 Tries to parse the selected attributes from @ARGV.
 
-=head2 command_check_attribute
-
- my ($error) = $self->command_check_attribute($attribute_meta_class,$value);
-
-Checks if a value is valid for the given attribute. Returns a message object
-if a validation error occurs.
-
-=head2 command_type_constraint_description
-
- my ($description) = $self->command_type_constraint_description($type_constraint);
-
-Returns a human-readable type constraint description.
-
 =head2 command_scan_namespace
  
  my %namespaces = $self->command_scan_namespace($namespace);
@@ -988,7 +935,7 @@ Returns a human-readable type constraint description.
 Scans a namespace for command classes. Returns a hash with command names
 as keys and package names as values.
 
-=head2 command_process_attributes
+=head2 command_process_attribute
 
  my @attributes = $self->command_process_attributes($metaclass,[qw(option proto)]);
  my @attributes = $self->command_process_attributes($metaclass,'parameter');
@@ -1006,4 +953,17 @@ Returns the options usage as a message object
  my $usage = $self->command_usage_parameters($metaclass,$headline);
 
 Returns the positional parameters usage as a message object
+
+=head2 command_check_attributes
+
+ $errors = $self->command_check_attributes($command_meta,$errors,$params)
+ 
+Checks all attributes. Returns/alters the $errors arrayref
+
+=head2 command_parser_hints
+
+ $self->command_parser_hints($self,$metaclass)
+
+Generates parser hints as required by L<MooseX::App::ParsedArgv>
+
 =cut
